@@ -11,7 +11,10 @@ use strict;
 use warnings;
 use autodie;
 
-use parent 'Test::Class';
+use parent (
+    'TestHTTPCpanelMixin',
+    'Test::Class',
+);
 
 use Test::More;
 use Test::Deep;
@@ -163,81 +166,89 @@ sub simple_with_token : Tests(2) {
     return;
 }
 
+sub why_u_no_create_session { undef }
+
 sub simple_with_password_and_tfa_token : Tests(4) {
     my ($self) = shift;
 
-    my $remote_cp = $self->CREATE(
-        service => 'cpanel',
+  SKIP: {
+        my $why_skip = $self->why_u_no_create_session();
 
-        credentials => {
-            username => 'johnny',
-            password => 'mysecret',
-            tfa_token => 'mytfa',
-        },
-    );
+        skip $why_skip, $self->num_tests() if $why_skip;
 
-    my $got = $self->AWAIT( $remote_cp->call_uapi( 'Email', 'list_forwarders' ) );
+        my $remote_cp = $self->CREATE(
+            service => 'cpanel',
 
-    cmp_deeply(
-        $got,
-        all(
-            methods(
-                [ isa => 'cPanel::APIClient::Response::UAPI' ] => bool(1),
-                succeeded                                      => 1,
-                get_data                                       => {
-                    content => q<>,
-                    method  => 'POST',
-                    uri     => '/cpses123123123/execute/Email/list_forwarders',
-                    headers => ignore(),
-                },
+            credentials => {
+                username => 'johnny',
+                password => 'mysecret',
+                tfa_token => 'mytfa',
+            },
+        );
+
+        my $got = $self->AWAIT( $remote_cp->call_uapi( 'Email', 'list_forwarders' ) );
+
+        cmp_deeply(
+            $got,
+            all(
+                methods(
+                    [ isa => 'cPanel::APIClient::Response::UAPI' ] => bool(1),
+                    succeeded                                      => 1,
+                    get_data                                       => {
+                        content => q<>,
+                        method  => 'POST',
+                        uri     => '/cpses123123123/execute/Email/list_forwarders',
+                        headers => ignore(),
+                    },
+                ),
+                listmethods(
+                    get_errors   => [],
+                    get_warnings => [],
+                    get_messages => [],
+                ),
             ),
-            listmethods(
-                get_errors   => [],
-                get_warnings => [],
-                get_messages => [],
+            'UAPI response',
+        ) or diag explain $got;
+
+        my %headers = @{ $got->get_data()->{'headers'} };
+
+        cmp_deeply(
+            \%headers,
+            superhashof(
+                {
+                    'Content-Type' => 'application/x-www-form-urlencoded',
+                    Cookie => ignore(),
+                }
             ),
-        ),
-        'UAPI response',
-    ) or diag explain $got;
+            'headers',
+        ) or diag explain \%headers;
 
-    my %headers = @{ $got->get_data()->{'headers'} };
+        my @cookies = sort split m<\s*;\s*>, $headers{'Cookie'};
 
-    cmp_deeply(
-        \%headers,
-        superhashof(
-            {
-                'Content-Type' => 'application/x-www-form-urlencoded',
-                Cookie => ignore(),
-            }
-        ),
-        'headers',
-    ) or diag explain \%headers;
+        cmp_bag(
+            \@cookies,
+            [
+                'cpsession=johnny%3a3KCfM88PHoZ4MoUf%2ce95011e2b6a51118250861a505638a8c',
+                ignore(),
+            ],
+            'session cookie sent',
+        );
 
-    my @cookies = sort split m<\s*;\s*>, $headers{'Cookie'};
+        $cookies[1] =~ s<\Alogin=><> or die "bad login cookie: $cookies[1]";
+        my $login  = URI::Escape::uri_unescape( $cookies[1] );
+        my @params = split m<&>, $login;
 
-    cmp_bag(
-        \@cookies,
-        [
-            'cpsession=johnny%3a3KCfM88PHoZ4MoUf%2ce95011e2b6a51118250861a505638a8c',
-            ignore(),
-        ],
-        'session cookie sent',
-    );
-
-    $cookies[1] =~ s<\Alogin=><> or die "bad login cookie: $cookies[1]";
-    my $login  = URI::Escape::uri_unescape( $cookies[1] );
-    my @params = split m<&>, $login;
-
-    cmp_bag(
-        \@params,
-        [
-            'user=johnny',
-            'pass=mysecret',
-            'tfa_token=mytfa',
-            'login_only=1',
-        ],
-        'login parameters',
-    ) or diag explain \@params;
+        cmp_bag(
+            \@params,
+            [
+                'user=johnny',
+                'pass=mysecret',
+                'tfa_token=mytfa',
+                'login_only=1',
+            ],
+            'login parameters',
+        ) or diag explain \@params;
+    }
 
     return;
 }
